@@ -1,13 +1,18 @@
 /*
  * Copyright 2020 2021 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "locationquerymodel.h"
+
 #include <QDebug>
 #include <QTimer>
+
+#include "weatherforecastmanager.h"
+#include "weatherlocationmodel.h"
+
 LocationQueryModel::LocationQueryModel()
 {
     inputTimer = new QTimer(this);
@@ -22,6 +27,15 @@ int LocationQueryModel::rowCount(const QModelIndex &parent) const
     return m_results.size();
 }
 
+static QString buildResultName(const KWeatherCore::LocationQueryResult &result)
+{
+    const auto &countryCode = result.countryCode();
+    if (result.subdivision() && countryCode == QLatin1String("US")) {
+        return result.toponymName() + QLatin1String(", ") + *result.subdivision() + QLatin1String(" | ") + result.countryName();
+    }
+    return result.toponymName() + QLatin1String(" | ") + result.countryName();
+}
+
 QVariant LocationQueryModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid())
@@ -30,7 +44,7 @@ QVariant LocationQueryModel::data(const QModelIndex &index, int role) const
     auto result = m_results.at(index.row());
 
     if (role == NameRole) {
-        return result.toponymName() + ", " + result.countryName();
+        return buildResultName(result);
     }
 
     return QVariant();
@@ -50,14 +64,14 @@ KWeatherCore::LocationQueryResult LocationQueryModel::get(int index)
 
 void LocationQueryModel::textChanged(QString query, int timeout)
 {
-    m_text = query;
+    m_text = std::move(query);
 
     beginResetModel();
     // clear results list
     m_results.clear();
 
     endResetModel();
-    if (!query.isEmpty()) { // do not query nothing
+    if (!m_text.isEmpty()) { // do not query nothing
         m_loading = true;
         m_networkError = false;
         Q_EMIT propertyChanged();
@@ -76,7 +90,7 @@ void LocationQueryModel::addLocation(int index)
 {
     if (m_results.empty() || index < 0 || index >= static_cast<int>(m_results.size()))
         return; // don't add location
-    Q_EMIT appendLocation(m_results.at(index));
+    WeatherForecastManager::inst()->model()->addLocation(m_results.at(index));
 }
 
 void LocationQueryModel::handleQueryResults(const std::vector<KWeatherCore::LocationQueryResult> &results)
@@ -89,9 +103,6 @@ void LocationQueryModel::handleQueryResults(const std::vector<KWeatherCore::Loca
     endResetModel();
 }
 
-void LocationQueryModel::updateUi()
-{
-}
 bool LocationQueryModel::loading() const
 {
     return m_loading;
