@@ -1,6 +1,6 @@
 /*
- * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
+ * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -24,14 +24,14 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
+#include "formatter.h"
 #include "kweathersettings.h"
 #include "locationquerymodel.h"
-#include "weatherdaymodel.h"
+#include "temperaturechartdata.h"
+#include "version.h"
 #include "weatherforecastmanager.h"
-#include "weatherhourmodel.h"
 #include "weatherlocation.h"
 #include "weatherlocationmodel.h"
-#include "version.h"
 
 class AbstractHourlyWeatherForecast;
 class AbstractDailyWeatherForecast;
@@ -45,7 +45,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QQuickStyle::setStyle(QStringLiteral("Material"));
 #else
     QApplication app(argc, argv);
-    if(qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 #endif
@@ -53,28 +53,28 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain("kweather");
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    KAboutData aboutData("kweather", i18n("Weather"), QStringLiteral(KWEATHER_VERSION_STRING), i18n("A convergent weather application for Plasma"), KAboutLicense::GPL, i18n("© 2020-2021 Plasma Development Team"));
+    KAboutData aboutData(QStringLiteral("kweather"),
+                         i18n("Weather"),
+                         QStringLiteral(KWEATHER_VERSION_STRING),
+                         i18n("A convergent weather application for Plasma"),
+                         KAboutLicense::GPL,
+                         i18n("© 2020-2021 Plasma Development Team"));
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("espidev@gmail.com"), QStringLiteral("https://espi.dev"));
     KAboutData::setApplicationData(aboutData);
 
     engine.rootContext()->setContextProperty(QStringLiteral("kweatherAboutData"), QVariant::fromValue(aboutData));
 
-    // initialize models in context
-    auto *locationQueryModel = new LocationQueryModel();
-    QObject::connect(locationQueryModel, &LocationQueryModel::appendLocation, WeatherForecastManager::inst()->model(), &WeatherLocationListModel::addLocation);
-    KWeatherSettings settings;
+    engine.rootContext()->setContextProperty(QStringLiteral("weatherLocationListModel"), WeatherForecastManager::inst()->model());
+    engine.rootContext()->setContextProperty(QStringLiteral("settingsModel"), KWeatherSettings::self());
 
-    engine.rootContext()->setContextProperty("weatherLocationListModel", WeatherForecastManager::inst()->model());
-    engine.rootContext()->setContextProperty("settingsModel", &settings);
-    engine.rootContext()->setContextProperty("locationQueryModel", locationQueryModel);
+    Formatter formatter;
+    qmlRegisterSingletonInstance<Formatter>("kweather", 1, 0, "Formatter", &formatter);
 
-    // register QML types
-    qmlRegisterType<WeatherLocation>("kweather", 1, 0, "WeatherLocation");
-    qmlRegisterType<WeatherDay>("kweather", 1, 0, "WeatherDay");
-    qmlRegisterType<WeatherHour>("kweather", 1, 0, "WeatherHour");
-    qmlRegisterType<WeatherHourListModel>("kweather", 1, 0, "WeatherHourListModel");
-    qmlRegisterType<WeatherDayListModel>("kweather", 1, 0, "WeatherDayListModel");
+    qmlRegisterType<TemperatureChartData>("kweather", 1, 0, "TemperatureChartData");
+    qmlRegisterType<LocationQueryModel>("kweather", 1, 0, "LocationQueryModel");
+
+    qRegisterMetaType<KWeatherCore::Sunrise>();
 
     // load setup wizard if first launch
     engine.load(QUrl(QStringLiteral("qrc:///qml/main.qml")));
