@@ -1,6 +1,6 @@
 /*
- * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
+ * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -27,10 +27,6 @@ public:
     {
         return m_model;
     }
-signals:
-    void updated();
-private slots:
-    void update();
 
 private:
     WeatherLocationListModel *m_model;
