@@ -1,34 +1,32 @@
 /*
- * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
+ * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2021 Nicolas Fella <nicolas.fella@gmx.de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "weatherlocation.h"
-#include "global.h"
-#include "locationquerymodel.h"
-#include "weatherdaymodel.h"
-#include "kweathersettings.h"
+
 #include <QDir>
-#include <QTimer>
 #include <QFile>
 #include <QJsonArray>
 #include <QQmlEngine>
 #include <QTimeZone>
+#include <QTimer>
+
 #include <utility>
 
-WeatherLocation::WeatherLocation()
-{
-    m_weatherDayListModel = new WeatherDayListModel(this);
-    m_weatherHourListModel = new WeatherHourListModel(this);
-    m_lastUpdated = QDateTime::currentDateTime();
-    this->m_timer = new QTimer(this);
-    connect(m_timer, &QTimer::timeout, this, &WeatherLocation::updateCurrentDateTime);
-    this->m_timer->start(60 - QDateTime::currentDateTime().currentMSecsSinceEpoch() % 60);
-}
+#include "global.h"
+#include "kweathersettings.h"
+#include "locationquerymodel.h"
 
-WeatherLocation::WeatherLocation(QString locationId, QString locationName, QString timeZone, float latitude, float longitude, SharedForecastPtr forecast)
+WeatherLocation::WeatherLocation(QString locationId,
+                                 QString locationName,
+                                 QString timeZone,
+                                 float latitude,
+                                 float longitude,
+                                 KWeatherCore::WeatherForecast forecast)
     : m_forecast(forecast)
     , m_locationName(std::move(locationName))
     , m_locationId(std::move(locationId))
@@ -36,34 +34,43 @@ WeatherLocation::WeatherLocation(QString locationId, QString locationName, QStri
     , m_latitude(latitude)
     , m_longitude(longitude)
 {
-    m_weatherDayListModel = new WeatherDayListModel(this);
-    m_weatherHourListModel = new WeatherHourListModel(this);
     this->m_timer = new QTimer(this);
     connect(m_timer, &QTimer::timeout, this, &WeatherLocation::updateCurrentDateTime);
     this->m_timer->start(60 - QDateTime::currentDateTime().currentMSecsSinceEpoch() % 60);
 
-    // prevent segfaults from js garbage collection
-    QQmlEngine::setObjectOwnership(m_weatherDayListModel, QQmlEngine::CppOwnership);
-    QQmlEngine::setObjectOwnership(m_weatherHourListModel, QQmlEngine::CppOwnership);
+    m_lastUpdated = forecast.createdTime();
 
-    if (forecast) {
-        m_lastUpdated = forecast->createdTime();
-        determineCurrentForecast();
-    }
+    update();
+
+    determineCurrentForecast();
+
+    connect(this, &WeatherLocation::selectedDayChanged, this, [this] {
+        m_hourForecasts.clear();
+        if (!m_forecast.dailyWeatherForecast().empty()) {
+            const auto hourForecasts = m_forecast.dailyWeatherForecast()[m_selectedDay].hourlyWeatherForecast();
+            for (const KWeatherCore::HourlyWeatherForecast &hour : hourForecasts) {
+                m_hourForecasts << QVariant::fromValue(hour);
+            }
+        }
+        Q_EMIT hourForecastsChanged();
+    });
 }
 WeatherLocation *WeatherLocation::load(const QString &groupName)
 {
-    auto config = KWeatherSettings().sharedConfig()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(groupName);
+    auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(groupName);
     if (config.isValid()) {
-        return new WeatherLocation(groupName, config.readEntry("locationName"), config.readEntry("timezone"), config.readEntry("latitude").toFloat(),
-                            config.readEntry("longitude").toFloat());
+        return new WeatherLocation(groupName,
+                                   config.readEntry("locationName"),
+                                   config.readEntry("timezone"),
+                                   config.readEntry("latitude").toFloat(),
+                                   config.readEntry("longitude").toFloat());
     } else {
         return nullptr;
     }
 }
 void WeatherLocation::save()
 {
-    auto config = KWeatherSettings(this).sharedConfig()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
+    auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
     config.writeEntry("locationName", locationName());
     config.writeEntry("latitude", latitude());
     config.writeEntry("longitude", longitude());
@@ -73,13 +80,13 @@ void WeatherLocation::save()
 
 void WeatherLocation::saveOrder(int index)
 {
-    auto config = KWeatherSettings(this).sharedConfig()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
+    auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
     config.writeEntry("index", index);
     config.sync();
 }
 int WeatherLocation::index()
 {
-    auto config = KWeatherSettings(this).sharedConfig()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
+    auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP).group(locationId());
     auto res = config.readEntry("index");
     if (res.isEmpty()) {
         return -1;
@@ -89,37 +96,51 @@ int WeatherLocation::index()
 }
 void WeatherLocation::deleteConfig()
 {
-    auto config = KWeatherSettings(this).sharedConfig()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP);
+    auto config = KWeatherSettings::self()->config()->group(Kweather::WEATHER_LOCATIONS_CFG_GROUP);
     config.deleteGroup(locationId());
     config.sync();
 }
-void WeatherLocation::updateData(QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast> forecasts)
+void WeatherLocation::updateData(KWeatherCore::WeatherForecast forecasts)
 {
     m_forecast = forecasts;
 
     // first time the timezone is empty
     if (m_timeZone.isEmpty()) {
-        m_timeZone = forecasts->timezone();
+        m_timeZone = forecasts.timezone();
         save();
     }
 
     determineCurrentForecast();
-    updateChart();
-    m_lastUpdated = forecasts->createdTime();
+    m_lastUpdated = forecasts.createdTime();
 
-    emit weatherRefresh(m_forecast);
-    emit stopLoadingIndicator();
+    m_hourForecasts.clear();
+    if (!m_forecast.dailyWeatherForecast().empty()) {
+        const auto hourForecasts = m_forecast.dailyWeatherForecast()[m_selectedDay].hourlyWeatherForecast();
+        for (const KWeatherCore::HourlyWeatherForecast &hour : hourForecasts) {
+            m_hourForecasts << QVariant::fromValue(hour);
+        }
+    }
+    Q_EMIT hourForecastsChanged();
 
-    emit propertyChanged();
+    m_dayForecasts.clear();
+    for (const KWeatherCore::DailyWeatherForecast &day : m_forecast.dailyWeatherForecast()) {
+        m_dayForecasts << QVariant::fromValue(day);
+    }
+    Q_EMIT dayForecastsChanged();
+
+    Q_EMIT weatherRefresh(m_forecast);
+    Q_EMIT stopLoadingIndicator();
+
+    Q_EMIT propertyChanged();
     updateCurrentDateTime();
 }
 
 void WeatherLocation::determineCurrentForecast()
 {
-    if (m_forecast->dailyWeatherForecast().empty())
+    if (m_forecast.dailyWeatherForecast().empty())
         return;
 
-    auto currentWeather = m_forecast->dailyWeatherForecast().begin()->hourlyWeatherForecast().begin();
+    auto currentWeather = m_forecast.dailyWeatherForecast().begin()->hourlyWeatherForecast().begin();
     m_backgroundComponent = QStringLiteral("backgrounds/ClearDay.qml");
 
     bool isDayStyle = false; // make sure that if the background is definitively day, the colours match that
@@ -177,14 +198,16 @@ void WeatherLocation::determineCurrentForecast()
         m_backgroundColor = QStringLiteral("#3daee2");
         m_textColor = m_cardTextColor;
         m_iconColor = QStringLiteral("#4d4d4d");
+        m_isDarkTheme = false;
     } else {
         m_cardBackgroundColor = QStringLiteral("#333333");
         m_cardTextColor = QStringLiteral("#eeeeee");
         m_backgroundColor = QStringLiteral("#222222");
         m_textColor = m_cardTextColor;
         m_iconColor = QStringLiteral("white");
+        m_isDarkTheme = true;
     }
-    emit currentForecastChange();
+    Q_EMIT currentForecastChange();
 }
 
 void WeatherLocation::update()
@@ -200,30 +223,17 @@ void WeatherLocation::update()
         });
 }
 
-void WeatherLocation::updateChart()
-{
-    m_maxTempList.clear();
-    m_xAxisList.clear();
-    for (const auto &day : m_forecast->dailyWeatherForecast()) {
-        m_maxTempList.append(day.maxTemp());
-        m_xAxisList.append(QLocale::system().toString(day.date(), QStringLiteral("ddd")));
-    }
-
-    Q_EMIT chartListChanged();
-}
-
-const QVariantList &WeatherLocation::maxTempList()
-{
-    return m_maxTempList;
-}
-const QVariantList &WeatherLocation::xAxisList()
-{
-    return m_xAxisList;
-}
-
 void WeatherLocation::updateCurrentDateTime()
 {
     m_timer->setInterval(60000);
     Q_EMIT currentTimeChanged();
     Q_EMIT currentDateChanged();
 }
+
+KWeatherCore::DailyWeatherForecast WeatherLocation::todayForecast() const
+{
+    if (!m_dayForecasts.isEmpty()) {
+        return m_dayForecasts.first().value<KWeatherCore::DailyWeatherForecast>();
+    }
+    return {};
+}
