@@ -1,15 +1,15 @@
 /*
- * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
+ * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2021 Nicolas Fella <nicolas.fella@gmx.de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
-#include "weatherhourmodel.h"
 
-#include <KWeatherCore/WeatherForecastSource>
 #include <QAbstractListModel>
+#include <QColor>
 #include <QDateTime>
 #include <QDebug>
 #include <QJsonDocument>
@@ -17,9 +17,19 @@
 #include <QObject>
 #include <QTimeZone>
 #include <QTimer>
+
+#include <KWeatherCore/WeatherForecastSource>
+
 #include <utility>
-using SharedForecastPtr = QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast>;
-class WeatherDayListModel;
+
+namespace QtCharts
+{
+class QAbstractSeries;
+class QSplineSeries;
+class QDateTimeAxis;
+class QValueAxis;
+}
+
 class WeatherLocation : public QObject
 {
     Q_OBJECT
@@ -27,8 +37,10 @@ class WeatherLocation : public QObject
     Q_PROPERTY(QString lastUpdated READ lastUpdatedFormatted NOTIFY propertyChanged)
     Q_PROPERTY(QString currentTime READ currentTimeFormatted NOTIFY currentTimeChanged)
     Q_PROPERTY(QString currentDate READ currentDateFormatted NOTIFY currentDateChanged)
-    Q_PROPERTY(WeatherDayListModel *dayListModel READ weatherDayListModel NOTIFY propertyChanged)
-    Q_PROPERTY(WeatherHourListModel *hourListModel READ weatherHourListModel NOTIFY propertyChanged)
+    Q_PROPERTY(QVariantList dayForecasts READ dayForecasts NOTIFY dayForecastsChanged)
+    Q_PROPERTY(QVariantList hourForecasts READ hourForecasts NOTIFY hourForecastsChanged)
+    Q_PROPERTY(int selectedDay READ selectedDay WRITE setSelectedDay NOTIFY selectedDayChanged)
+    Q_PROPERTY(KWeatherCore::DailyWeatherForecast todayForecast READ todayForecast NOTIFY dayForecastsChanged)
 
     Q_PROPERTY(QString backgroundComponent READ backgroundComponent NOTIFY currentForecastChange)
     Q_PROPERTY(QColor backgroundColor READ backgroundColor NOTIFY currentForecastChange)
@@ -36,20 +48,17 @@ class WeatherLocation : public QObject
     Q_PROPERTY(QColor cardBackgroundColor READ cardBackgroundColor NOTIFY currentForecastChange)
     Q_PROPERTY(QColor cardTextColor READ cardTextColor NOTIFY currentForecastChange)
     Q_PROPERTY(QColor iconColor READ iconColor NOTIFY currentForecastChange)
+    Q_PROPERTY(bool darkTheme READ darkTheme NOTIFY currentForecastChange)
 
-    Q_PROPERTY(QVariantList maxTempList READ maxTempList NOTIFY chartListChanged)
-    Q_PROPERTY(QVariantList xAxisList READ xAxisList NOTIFY chartListChanged)
 public:
-    WeatherLocation();
     explicit WeatherLocation(QString locationId,
                              QString locationName,
                              QString timeZone,
                              float latitude,
                              float longitude,
-                             SharedForecastPtr forecast = SharedForecastPtr(new KWeatherCore::WeatherForecast));
+                             KWeatherCore::WeatherForecast forecast = {});
     void save();
     static WeatherLocation *load(const QString &groupName);
-    WeatherHour *currentWeather() const;
     Q_INVOKABLE void update();
 
     const QString &locationId() const
@@ -72,17 +81,9 @@ public:
     {
         return m_longitude;
     }
-    WeatherDayListModel *weatherDayListModel() const
-    {
-        return m_weatherDayListModel;
-    }
-    WeatherHourListModel *weatherHourListModel() const
-    {
-        return m_weatherHourListModel;
-    }
     QString lastUpdatedFormatted() const
     {
-        return lastUpdated().toString("hh:mm ap");
+        return lastUpdated().toString(QStringLiteral("hh:mm ap"));
     }
     const QDateTime &lastUpdated() const
     {
@@ -90,11 +91,11 @@ public:
     }
     QString currentTimeFormatted() const
     {
-        return currentDateTime().toString("hh:mm ap");
+        return currentDateTime().toString(QStringLiteral("hh:mm ap"));
     }
     QString currentDateFormatted() const
     {
-        return currentDateTime().toString("dd MMM yyyy");
+        return currentDateTime().toString(QStringLiteral("dd MMM yyyy"));
     }
     QDateTime currentDateTime() const
     {
@@ -103,7 +104,7 @@ public:
     void setLastUpdated(QDateTime lastUpdated)
     {
         m_lastUpdated = std::move(lastUpdated);
-        emit propertyChanged();
+        Q_EMIT propertyChanged();
     }
     const QString &backgroundComponent() const
     {
@@ -130,37 +131,58 @@ public:
     {
         return m_iconColor;
     }
-
-    const QVariantList &maxTempList();
-    const QVariantList &xAxisList();
+    bool darkTheme() const
+    {
+        return m_isDarkTheme;
+    }
+    QVariantList dayForecasts() const
+    {
+        return m_dayForecasts;
+    }
+    QVariantList hourForecasts() const
+    {
+        return m_hourForecasts;
+    }
+    int selectedDay() const
+    {
+        return m_selectedDay;
+    }
+    void setSelectedDay(int selectedDay)
+    {
+        if (selectedDay != m_selectedDay) {
+            m_selectedDay = selectedDay;
+            Q_EMIT selectedDayChanged();
+        }
+    }
+    KWeatherCore::DailyWeatherForecast todayForecast() const;
 
     // for restore order of locations
     void saveOrder(int index);
     int index();
     void deleteConfig();
-public slots:
-    void updateData(QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast> forecasts);
+public Q_SLOTS:
+    void updateData(KWeatherCore::WeatherForecast forecasts);
 
-signals:
-    void weatherRefresh(QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast> forecasts); // sent when weather data is refreshed
+Q_SIGNALS:
+    void weatherRefresh(KWeatherCore::WeatherForecast forecasts); // sent when weather data is refreshed
     void currentForecastChange();
     void propertyChanged(); // avoid warning
     void stopLoadingIndicator();
     void currentTimeChanged();
     void currentDateChanged();
+    void dayForecastsChanged();
+    void hourForecastsChanged();
+    void selectedDayChanged();
 
     void chartListChanged();
-private slots:
+private Q_SLOTS:
     void updateCurrentDateTime();
 
 private:
     void determineCurrentForecast();
 
     KWeatherCore::WeatherForecastSource m_source;
-    SharedForecastPtr m_forecast;
-
-    // chart related fields
-    QVariantList m_maxTempList, m_xAxisList;
+    KWeatherCore::WeatherForecast m_forecast;
 
     // background related fields
     QColor m_backgroundColor;
@@ -169,6 +191,7 @@ private:
     QColor m_cardTextColor;
     QColor m_iconColor;
     QString m_backgroundComponent = QStringLiteral("backgrounds/ClearDay.qml");
+    bool m_isDarkTheme = false;
 
     QString m_locationName, m_locationId;
     QString m_timeZone;
@@ -176,8 +199,7 @@ private:
     QTimer *m_timer;
     float m_latitude, m_longitude;
 
-    WeatherDayListModel *m_weatherDayListModel = nullptr;
-    WeatherHourListModel *m_weatherHourListModel = nullptr;
-
-    void updateChart();
+    QVariantList m_dayForecasts;
+    QVariantList m_hourForecasts;
+    int m_selectedDay = 0;
 };
